@@ -19,9 +19,9 @@
 */
 
 
-#include <tabbar.h>
-#include <mainwindow.h>
-#include <skin.h>
+#include "tabbar.h"
+#include "mainwindow.h"
+#include "skin.h"
 
 #include <KLineEdit>
 #include <KMenu>
@@ -179,17 +179,6 @@ void TabBar::paintEvent(QPaintEvent*)
     QPainter painter(this);
     painter.setPen(m_skin->tabBarTextColor());
 
-    if (m_mainWindow->useTranslucency())
-    {
-        painter.setCompositionMode(QPainter::CompositionMode_Source);
-        painter.fillRect(rect(), Qt::transparent);
-    }
-    else
-    {
-        painter.setCompositionMode(QPainter::CompositionMode_SourceOver);
-        painter.fillRect(rect(), Settings::backgroundColor());
-    }
-
     QString title;
     int sessionId;
     bool selected;
@@ -372,10 +361,14 @@ void TabBar::leaveEvent(QEvent* event)
     QWidget::leaveEvent(event);
 }
 
-void TabBar::addTab(int sessionId)
+void TabBar::addTab(int sessionId, const QString& title)
 {
     m_tabs.append(sessionId);
-    m_tabTitles.insert(sessionId, standardTabTitle());
+
+    if (title.isEmpty())
+        m_tabTitles.insert(sessionId, standardTabTitle());
+    else
+        m_tabTitles.insert(sessionId, title);
 
     emit tabSelected(sessionId);
 }
@@ -486,6 +479,8 @@ void TabBar::moveTabLeft(int sessionId)
     m_tabs.swap(index, index - 1);
 
     repaint();
+
+    updateMoveActions(index - 1);
 }
 
 void TabBar::moveTabRight(int sessionId)
@@ -500,6 +495,8 @@ void TabBar::moveTabRight(int sessionId)
     m_tabs.swap(index, index + 1);
 
     repaint();
+
+    updateMoveActions(index + 1);
 }
 
 void TabBar::closeTabButtonClicked()
